Python: built-in module exceptions

exceptions | index

`Python's standard exception class hierarchy.
Exceptions found here are defined both in the exceptions module and the
built-in namespace. It is recommended that user-defined exceptions
inherit from Exception. See the documentation for the exception
inheritance hierarchy.`

Classes
`` |  | __builtin__.object BaseException Exception PipInstallFailed StandardError ArithmeticError FloatingPointError OverflowError ZeroDivisionError AssertionError AttributeError BufferError EOFError EnvironmentError IOError OSError ImportError LookupError IndexError KeyError MemoryError NameError UnboundLocalError ReferenceError RuntimeError NotImplementedError SyntaxError IndentationError TabError SystemError TypeError ValueError UnicodeError UnicodeDecodeError UnicodeEncodeError UnicodeTranslateError StopIteration Warning BytesWarning DeprecationWarning FutureWarning ImportWarning PendingDeprecationWarning RuntimeWarning SyntaxWarning UnicodeWarning UserWarning GeneratorExit KeyboardInterrupt SystemExit
class ArithmeticError(StandardError)
`` | `Base class for arithmetic errors.`
| Method resolution order: ArithmeticError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class AssertionError(StandardError)
`` | `Assertion failed.`
| Method resolution order: AssertionError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class AttributeError(StandardError)
`` | `Attribute not found.`
| Method resolution order: AttributeError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class BaseException(__builtin__.object)
`` | `Common base class for all exceptions`
| Methods defined here: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors defined here: __dict__ args message Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T`
class BufferError(StandardError)
`` | `Buffer error.`
| Method resolution order: BufferError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class BytesWarning(Warning)
`` | `Base class for warnings about bytes and buffer related problems, mostly related to conversion from str or comparing to str.`
| Method resolution order: BytesWarning Warning Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class DeprecationWarning(Warning)
`` | `Base class for warnings about deprecated features.`
| Method resolution order: DeprecationWarning Warning Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class EOFError(StandardError)
`` | `Read beyond end of file.`
| Method resolution order: EOFError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class EnvironmentError(StandardError)
`` | `Base class for I/O related errors.`
| Method resolution order: EnvironmentError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __reduce__(...) __str__(...) `x.__str__() <==> str(x)` Data descriptors defined here: errno `exception errno` filename `exception filename` strerror `exception strerror` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class Exception(BaseException)
`` | `Common base class for all non-exit exceptions.`
| Method resolution order: Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class FloatingPointError(ArithmeticError)
`` | `Floating point operation failed.`
| Method resolution order: FloatingPointError ArithmeticError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class FutureWarning(Warning)
`` | `Base class for warnings about constructs that will change semantically in the future.`
| Method resolution order: FutureWarning Warning Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class GeneratorExit(BaseException)
`` | `Request that a generator exit.`
| Method resolution order: GeneratorExit BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class IOError(EnvironmentError)
`` | `I/O operation failed.`
| Method resolution order: IOError EnvironmentError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from EnvironmentError: __reduce__(...) __str__(...) `x.__str__() <==> str(x)` Data descriptors inherited from EnvironmentError: errno `exception errno` filename `exception filename` strerror `exception strerror` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class ImportError(StandardError)
`` | `Import can't find module, or can't find name in module.`
| Method resolution order: ImportError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class ImportWarning(Warning)
`` | `Base class for warnings about probable mistakes in module imports`
| Method resolution order: ImportWarning Warning Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class IndentationError(SyntaxError)
`` | `Improper indentation.`
| Method resolution order: IndentationError SyntaxError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from SyntaxError: __str__(...) `x.__str__() <==> str(x)` Data descriptors inherited from SyntaxError: filename `exception filename` lineno `exception lineno` msg `exception msg` offset `exception offset` print_file_and_line `exception print_file_and_line` text `exception text` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class IndexError(LookupError)
`` | `Sequence index out of range.`
| Method resolution order: IndexError LookupError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class KeyError(LookupError)
`` | `Mapping key not found.`
| Method resolution order: KeyError LookupError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __str__(...) `x.__str__() <==> str(x)` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class KeyboardInterrupt(BaseException)
`` | `Program interrupted by user.`
| Method resolution order: KeyboardInterrupt BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class LookupError(StandardError)
`` | `Base class for lookup errors.`
| Method resolution order: LookupError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class MemoryError(StandardError)
`` | `Out of memory.`
| Method resolution order: MemoryError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class NameError(StandardError)
`` | `Name not found globally.`
| Method resolution order: NameError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class NotImplementedError(RuntimeError)
`` | `Method or function hasn't been implemented yet.`
| Method resolution order: NotImplementedError RuntimeError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class OSError(EnvironmentError)
`` | `OS system call failed.`
| Method resolution order: OSError EnvironmentError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from EnvironmentError: __reduce__(...) __str__(...) `x.__str__() <==> str(x)` Data descriptors inherited from EnvironmentError: errno `exception errno` filename `exception filename` strerror `exception strerror` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class OverflowError(ArithmeticError)
`` | `Result too large to be represented.`
| Method resolution order: OverflowError ArithmeticError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class PendingDeprecationWarning(Warning)
`` | `Base class for warnings about features which will be deprecated in the future.`
| Method resolution order: PendingDeprecationWarning Warning Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class PipInstallFailed(Exception)
`` | `PipInstallFailed - Exception raised when pip fails to install a list of packages`
| Method resolution order: PipInstallFailed Exception BaseException __builtin__.object Methods defined here: __init__(self, returnCode=None, reqFileContents='') `Create a PipInstallFailed exception, building a message from some pieces of information @param returnCode <int> - Return code of subprocess, or None if undetermined @param reqFileContents <str> - String of requirements file to reproduce error` Data descriptors defined here: __weakref__ `list of weak references to the object (if defined)` Data and other attributes inherited from Exception: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class ReferenceError(StandardError)
`` | `Weak ref proxy used after referent went away.`
| Method resolution order: ReferenceError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class RuntimeError(StandardError)
`` | `Unspecified run-time error.`
| Method resolution order: RuntimeError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class RuntimeWarning(Warning)
`` | `Base class for warnings about dubious runtime behavior.`
| Method resolution order: RuntimeWarning Warning Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class StandardError(Exception)
`` | `Base class for all standard Python exceptions that do not represent interpreter exiting.`
| Method resolution order: StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class StopIteration(Exception)
`` | `Signal the end from iterator.next().`
| Method resolution order: StopIteration Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class SyntaxError(StandardError)
`` | `Invalid syntax.`
| Method resolution order: SyntaxError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __str__(...) `x.__str__() <==> str(x)` Data descriptors defined here: filename `exception filename` lineno `exception lineno` msg `exception msg` offset `exception offset` print_file_and_line `exception print_file_and_line` text `exception text` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class SyntaxWarning(Warning)
`` | `Base class for warnings about dubious syntax.`
| Method resolution order: SyntaxWarning Warning Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class SystemError(StandardError)
`` | `Internal error in the Python interpreter. Please report this to the Python maintainer, along with the traceback, the Python version, and the hardware/OS platform and version.`
| Method resolution order: SystemError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class SystemExit(BaseException)
`` | `Request to exit from the interpreter.`
| Method resolution order: SystemExit BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data descriptors defined here: code `exception code` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class TabError(IndentationError)
`` | `Improper mixture of spaces and tabs.`
| Method resolution order: TabError IndentationError SyntaxError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from SyntaxError: __str__(...) `x.__str__() <==> str(x)` Data descriptors inherited from SyntaxError: filename `exception filename` lineno `exception lineno` msg `exception msg` offset `exception offset` print_file_and_line `exception print_file_and_line` text `exception text` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class TypeError(StandardError)
`` | `Inappropriate argument type.`
| Method resolution order: TypeError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class UnboundLocalError(NameError)
`` | `Local name referenced but not bound to a value.`
| Method resolution order: UnboundLocalError NameError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class UnicodeDecodeError(UnicodeError)
`` | `Unicode decoding error.`
| Method resolution order: UnicodeDecodeError UnicodeError ValueError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __str__(...) `x.__str__() <==> str(x)` Data descriptors defined here: encoding `exception encoding` end `exception end` object `exception object` reason `exception reason` start `exception start` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class UnicodeEncodeError(UnicodeError)
`` | `Unicode encoding error.`
| Method resolution order: UnicodeEncodeError UnicodeError ValueError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __str__(...) `x.__str__() <==> str(x)` Data descriptors defined here: encoding `exception encoding` end `exception end` object `exception object` reason `exception reason` start `exception start` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class UnicodeError(ValueError)
`` | `Unicode related error.`
| Method resolution order: UnicodeError ValueError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class UnicodeTranslateError(UnicodeError)
`` | `Unicode translation error.`
| Method resolution order: UnicodeTranslateError UnicodeError ValueError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __str__(...) `x.__str__() <==> str(x)` Data descriptors defined here: encoding `exception encoding` end `exception end` object `exception object` reason `exception reason` start `exception start` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class UnicodeWarning(Warning)
`` | `Base class for warnings about Unicode related problems, mostly related to conversion problems.`
| Method resolution order: UnicodeWarning Warning Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class UserWarning(Warning)
`` | `Base class for warnings generated by user code.`
| Method resolution order: UserWarning Warning Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class ValueError(StandardError)
`` | `Inappropriate argument value (of correct type).`
| Method resolution order: ValueError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class Warning(Exception)
`` | `Base class for warning categories.`
| Method resolution order: Warning Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message
class ZeroDivisionError(ArithmeticError)
`` | `Second argument to a division or modulo operation was zero.`
| Method resolution order: ZeroDivisionError ArithmeticError StandardError Exception BaseException __builtin__.object Methods defined here: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from BaseException: __dict__ args message